pub async fn install_chunked_code(
arg: &InstallChunkedCodeArgs,
) -> Result<(), Error>Expand description
Installs code into a canister where the code has previously been uploaded in chunks.
Unbounded-wait call
pub async fn install_chunked_code(
arg: &InstallChunkedCodeArgs,
) -> Result<(), Error>Installs code into a canister where the code has previously been uploaded in chunks.
Unbounded-wait call