Stable-structure re-exports plus a few small Canic wrappers.
Re-exports
pub use btreemap::BTreeMap;
Modules
- btreemap
- btreeset
- This module implements a set based on a B-Tree in stable memory.
- cell
- A serializable value stored in the stable memory.
- file_
mem - log
- An append-only list data structure, also known as log.
- memory
- memory_
manager - A module for simulating multiple memories within a single memory.
- min_
heap - reader
- storable
- vec
- This module implements a growable array in stable memory.
- vec_mem
- writer
Structs
- BTree
Map - A B-Tree map implementation that stores its data into a designated memory.
- BTree
Set - A B-Tree set implementation that stores its data into a designated memory.
- Cell
- Represents a value stored in stable memory.
- File
Memory - A
Memorybacked by a file. - Grow
Failed - Log
- Append-only list of variable-size entries stored in stable memory.
- MinHeap
- An implementation of the binary min heap.
- Restricted
Memory - RestrictedMemory creates a limited view of another memory. This allows one to divide the main memory into non-intersecting ranges and use different layouts in each region.
- StableB
Tree Map - A B-Tree map implementation that stores its data into a designated memory.
- StableB
Tree Set - A B-Tree set implementation that stores its data into a designated memory.
- Stable
Cell - Represents a value stored in stable memory.
- Stable
Log - Append-only list of variable-size entries stored in stable memory.
- Stable
MinHeap - An implementation of the binary min heap.
- Stable
Vec - An implementation of growable arrays in stable memory.
- Vec
- An implementation of growable arrays in stable memory.
Constants
- MAX_
PAGES - The maximum number of stable memory pages a canister can address.
Traits
- Memory
- Abstraction over a WebAssembly-style linear memory (e.g., stable memory).
- Storable
- A trait with convenience methods for storing an element into a stable structure.
Type Aliases
- Default
Memory Impl - Vector
Memory - A
Memorythat is based on a vector.